raytraverse.mapper
==========================================================

SkyMapper
------------------------------

.. autoclass:: raytraverse.mapper.SkyMapper
    :members:
    :undoc-members:
    :show-inheritance:

PlanMapper
------------------------------

.. autoclass:: raytraverse.mapper.PlanMapper
    :members:
    :undoc-members:
    :show-inheritance:

MaskedPlanMapper
------------------------------

.. autoclass:: raytraverse.mapper.MaskedPlanMapper
    :members:
    :undoc-members:
    :show-inheritance:
